// Fill out your copyright notice in the Description page of Project Settings.

#include "SimpleGame.h"
#include "GameFramework/ProjectileMovementComponent.h"
#include "PublicCharacter.h"
#include "Engine.h"
#include "SimpleGameProjectile.h"


// Sets default values
ASimpleGameProjectile::ASimpleGameProjectile()
{
	ProjectileCollision = CreateDefaultSubobject<USphereComponent>(TEXT("Sphere Comp"));
	ProjectileCollision->InitSphereRadius(20.0f);
	ProjectileCollision->BodyInstance.SetCollisionProfileName("Projectile");
	ProjectileCollision->OnComponentBeginOverlap.AddDynamic(this, &ASimpleGameProjectile::OnOverlapBegin);
	RootComponent = ProjectileCollision;

	ProjectileMovement = CreateDefaultSubobject<UProjectileMovementComponent>(TEXT("ProjectileComp"));
	ProjectileMovement->UpdatedComponent = ProjectileCollision;
	ProjectileMovement->InitialSpeed = 3000.0f;
	ProjectileMovement->MaxSpeed = 3000.0f;
	ProjectileMovement->bRotationFollowsVelocity = false;
	InitialLifeSpan = 3.0f;


}

void ASimpleGameProjectile::OnOverlapBegin(class AActor* OtherActor, class UPrimitiveComponent* OtherComp, int32 OtherBodyIndex, bool bFromSweep, const FHitResult& SweepResult)
{
	if (OtherActor && (OtherActor != this) && OtherComp)
	{
		Destroy();
		if (OtherActor->IsA(APublicCharacter::StaticClass()))
		{
			UGameplayStatics::ApplyPointDamage(SweepResult.Actor.Get(), 100, -SweepResult.ImpactNormal, SweepResult, NULL, this, UDamageType::StaticClass());
			GEngine->AddOnScreenDebugMessage(-1, 2.f, FColor::Black, "Collision Projectile!!");
		}
	}
}


